@@ -118,7 +118,7 @@
     <tags-item tags="prn.pro.*"/>
   </def-label>
   <def-label name="VA"><!--Afegit 10/11/05 MG -->
-    <tags-item lemma ="anar" tags="vblex.pri.*"/>
+    <tags-item lemma="anar" tags="vblex.pri.*"/>
   </def-label>
   <def-label name="VLEXINF">
     <tags-item tags="vblex.inf"/>
@@ -429,7 +429,7 @@
       <label-item label="NOMMF"/>
       <label-item label="NOMMF"/>
     </label-sequence>
-    <label-sequence>
+  <!--  <label-sequence>
       <label-item label="NOMM"/>
       <label-item label="ACRONIMOM"/>
     </label-sequence>
@@ -464,7 +464,7 @@
     <label-sequence>
       <label-item label="NOMMF"/>
       <label-item label="ACRONIMOMF"/>
-    </label-sequence>
+    </label-sequence> -->
     <label-sequence>
       <label-item label="ACRONIMOM"/>
       <label-item label="NOMM"/>
@@ -1513,6 +1513,12 @@
       <label-item label="ADV"/>
       <label-item label="INTERJ"/>
     </label-sequence>
+    <label-sequence><!--11/10/06 -->
+      <label-item label="VMODALPARTPI"/>
+      <label-item label="PREP"/>
+    </label-sequence>
+
+
 
   
   </forbid>
@@ -1571,5 +1577,9 @@
    <prefer tags="vbser.pis.p3.sg"/>
    <prefer tags="vbhaver.pis.p3.sg"/>
    <prefer tags="vbmod.pis.p3.sg"/>
+   <prefer tags="vblex.pri.p3.sg"/>
+   <prefer tags="vbser.pri.p3.sg"/>
+   <prefer tags="vbhaver.pri.p3.sg"/>
+   <prefer tags="vbmod.pri.p3.sg"/>
   </preferences>
 </tagger>
