@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="iso-8859-1"?>
 <tagger name="spanish">
 <tagset>
-  <def-label name="PARAPR" closed="true">
+<!--  <def-label name="PARAPR" closed="true">
     <tags-item lemma="para" tags="pr"/>
-  </def-label>
+  </def-label> -->
   <def-label name="PARAVBPRI" closed="true">
     <tags-item lemma="parar" tags="vblex.pri.p3.sg"/>
   </def-label>
@@ -109,6 +109,9 @@
     <tags-item tags="num.*"/>
     <tags-item tags="num"/>
   </def-label>
+  <def-label name="WEB" closed="true">
+    <tags-item tags="web"/>
+  </def-label>
   <def-label name="PREDETNT" closed="true">
     <tags-item tags="predet.nt.*"/>
   </def-label> 
@@ -136,58 +139,81 @@
   <def-label name="PRNPRO" closed="true">
     <tags-item tags="prn.pro.*"/>
   </def-label>
-  <def-label name="VLEXINF">
-    <tags-item tags="vblex.inf"/>
-  </def-label>
-  <def-label name="VLEXGER">
-    <tags-item tags="vblex.ger"/>
-  </def-label>
-  <def-label name="VLEXPARTPI">
-    <tags-item tags="vblex.pp.*"/>
-  </def-label>
-  <def-label name="VLEXPFCI">
-    <tags-item tags="vblex.pri.*"/>
-    <tags-item tags="vblex.fti.*"/>
-    <tags-item tags="vblex.cni.*"/>
-  </def-label>
-  <def-label name="VLEXIPI">
-    <tags-item tags="vblex.pii.*"/>
-    <tags-item tags="vblex.ifi.*"/>
-  </def-label>
-  <def-label name="VLEXSUBJ">
-    <tags-item tags="vblex.prs.*"/>
-    <tags-item tags="vblex.pis.*"/>
-    <tags-item tags="vblex.fts.*"/>
-  </def-label>
-  <def-label name="VLEXIMP">
-    <tags-item tags="vblex.imp.*"/>
-  </def-label>
   <def-label name="VSERINF" closed="true">
+    <tags-item lemma="estar" tags="vblex.inf"/>
     <tags-item tags="vbser.inf"/>
   </def-label>
   <def-label name="VSERGER" closed="true">
+    <tags-item lemma="estar" tags="vblex.ger"/>
     <tags-item tags="vbser.ger"/>
   </def-label>
   <def-label name="VSERPARTPI" closed="true">
     <tags-item tags="vbser.pp.*"/>
   </def-label>
   <def-label name="VSERPFCI" closed="true">
+    <tags-item lemma="estar" tags="vblex.pri.*"/>
+    <tags-item lemma="estar" tags="vblex.fti.*"/>    
+    <tags-item lemma="estar" tags="vblex.cni.*"/>
     <tags-item tags="vbser.pri.*"/>
     <tags-item tags="vbser.fti.*"/>
     <tags-item tags="vbser.cni.*"/>
   </def-label>
   <def-label name="VSERIPI" closed="true">
+    <tags-item lemma="estar" tags="vblex.pii.*"/>
+    <tags-item lemma="estar" tags="vblex.ifi.*"/>
     <tags-item tags="vbser.pii.*"/>
     <tags-item tags="vbser.ifi.*"/>
   </def-label>
   <def-label name="VSERSUBJ" closed="true">
+    <tags-item lemma="estar" tags="vblex.prs.*"/>
+    <tags-item lemma="estar" tags="vblex.pis.*"/>
+    <tags-item lemma="estar" tags="vblex.fts.*"/>
     <tags-item tags="vbser.prs.*"/>
     <tags-item tags="vbser.pis.*"/>
     <tags-item tags="vbser.fts.*"/>
   </def-label>
   <def-label name="VSERIMP" closed="true">
+    <tags-item lemma="estar" tags="vblex.imp.*"/>
     <tags-item tags="vbser.imp.*"/>
   </def-label>
+  <def-label name="VLEXINF">
+    <tags-item tags="vblex.inf"/>
+    <tags-item tags="vblex.v2.inf"/>
+  </def-label>
+  <def-label name="VLEXGER">
+    <tags-item tags="vblex.ger"/>
+    <tags-item tags="vblex.v2.ger"/>
+  </def-label>
+  <def-label name="VLEXPARTPI">
+    <tags-item tags="vblex.pp.*"/>
+    <tags-item tags="vblex.v2.pp.*"/>
+  </def-label>
+  <def-label name="VLEXPFCI">
+    <tags-item tags="vblex.pri.*"/>
+    <tags-item tags="vblex.fti.*"/>
+    <tags-item tags="vblex.cni.*"/>
+    <tags-item tags="vblex.v2.pri.*"/>
+    <tags-item tags="vblex.v2.fti.*"/>
+    <tags-item tags="vblex.v2.cni.*"/>
+  </def-label>
+  <def-label name="VLEXIPI">
+    <tags-item tags="vblex.pii.*"/>
+    <tags-item tags="vblex.ifi.*"/>
+    <tags-item tags="vblex.v2.pii.*"/>
+    <tags-item tags="vblex.v2.ifi.*"/>
+  </def-label>
+  <def-label name="VLEXSUBJ">
+    <tags-item tags="vblex.prs.*"/>
+    <tags-item tags="vblex.pis.*"/>
+    <tags-item tags="vblex.fts.*"/>
+    <tags-item tags="vblex.v2.prs.*"/>
+    <tags-item tags="vblex.v2.pis.*"/>
+    <tags-item tags="vblex.v2.fts.*"/>
+  </def-label>
+  <def-label name="VLEXIMP">
+    <tags-item tags="vblex.imp.*"/>
+    <tags-item tags="vblex.v2.imp.*"/>
+  </def-label>
   <def-label name="VHABERINF" closed="true">
     <tags-item tags="vbhaver.inf"/>
   </def-label>
@@ -454,6 +480,10 @@
       <label-item label="PREP"/>
       <label-item label="VLEXIMP"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="COMOPR"/>
+      <label-item label="VLEXIMP"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="PREP"/>
       <label-item label="IMPLEXPRNENC"/>
@@ -474,6 +504,10 @@
       <label-item label="PREP"/>
       <label-item label="VSERIMP"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="COMOPR"/>
+      <label-item label="VSERIMP"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="PREP"/>
       <label-item label="IMPSERPRNENC"/>
@@ -506,6 +540,10 @@
       <label-item label="PREP"/>
       <label-item label="VMODALIMP"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="COMOPR"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="PREP"/>
       <label-item label="IMPMODPRNENC"/>
@@ -1847,6 +1885,113 @@
       <label-item label="VMODALIMP"/>
       <label-item label="ADJPOS"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ADV"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="ADV"/>
+      <label-item label="VLEXIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="ADV"/>
+      <label-item label="VSERIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="VSERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="VSERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="VLEXINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="VLEXINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="VHABERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="VHABERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="INFLEXPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="INFLEXPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="INFSERPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="INFSERPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="INFHABERPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="INFHABERPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBPRI"/>
+      <label-item label="INFMODPRNENC"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PARAVBIMP"/>
+      <label-item label="INFMODPRNENC"/>
+    </label-sequence>
+
+
+    <label-sequence>
+      <label-item label="VMODALINF"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALGER"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALPARTPI"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALPFCI"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALIPI"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALSUBJ"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VMODALIMP"/>
+      <label-item label="CNJSUBS"/><!--no incluye 'que' -->
+    </label-sequence>
+
 
   </forbid>
 
